# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cms', '0020_old_tree_cleanup'),
        ('blog_extension', '0006_auto_20180927_0404'),
    ]

    operations = [
        migrations.CreateModel(
            name='DatePluginConfig',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(parent_link=True, related_name='blog_extension_datepluginconfig', auto_created=True, primary_key=True, serialize=False, to='cms.CMSPlugin', on_delete=models.CASCADE)),
                ('renderTemplate', models.CharField(default=b'blog_extension/Date.html', max_length=150, verbose_name='Render template', choices=[(b'blog_extension/Date.html', 'Default')])),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
    ]
